@@ -99,7 +99,7 @@ INIT {
 use strict;
 use warnings;
 
-our $VERSION = '1.003';
+our $VERSION = '1.004';
 $VERSION = eval $VERSION;
 
 use Fcntl qw( :flock O_CREAT O_TRUNC O_RDWR O_RDONLY );
@@ -2213,7 +2213,7 @@ MCE - Many-Core Engine for Perl. Provides parallel processing cabilities.
 
 =head1 VERSION
 
-This document describes MCE version 1.003
+This document describes MCE version 1.004
 
 =head1 SYNOPSIS
 
@@ -2282,7 +2282,7 @@ This document describes MCE version 1.003
     user_error   => \&user_error,   ## Default is undef
     user_output  => \&user_output,  ## Default is undef
 
-        ## When workers call the following funtions, MCE will
+        ## When workers call the following functions, MCE will
         ## pass the data to user_error/user_output if defined.
         ## $self->sendto('stderr', 'Sending to STDERR');
         ## $self->sendto('stdout', 'Sending to STDOUT');
@@ -2473,7 +2473,7 @@ the next n elements from the input stream to the next available worker.
 
 =head2 MCE EXAMPLE WITH CHUNK_SIZE => 500
 
- ## Chunking reduces overhead manyfolds. Instead of passing a single
+ ## Chunking reduces overhead many folds. Instead of passing a single
  ## item from @input_data, a chunk of $chunk_size is sent instead to
  ## the next available worker.
 
@@ -2671,7 +2671,7 @@ thread. In addition, the callback function can optionally return a reply.
 =head1 EXAMPLES
 
 MCE comes with various examples showing real-world use case scenarios on
-parallelizing something as small as cat (try with -n) to grepping for
+parallelizing something as small as cat (try with -n) to greping for
 patterns and word count aggregation.
 
  cat.pl    Concatenation script, similar to the cat binary.
@@ -2688,10 +2688,10 @@ patterns and word count aggregation.
            Perform ping test and report back failing IPs to
            standard output.
 
- widefinder.pl
-           An implementation utilizing MCE.
-           As fast as MMAP IO when file resides in OS FS cache
-           2x ~ 3x faster when reading directly from disk
+ tbray/wf_mce1.pl, wf_mce2.pl, wf_mce3.pl
+           An implementation of wide finder utilizing MCE.
+           As fast as MMAP IO when file resides in OS FS cache.
+           2x ~ 3x faster when reading directly from disk.
 
  foreach.pl
  forchunk.pl
